# Doesn't require any BIOS/copyrighted material, so it can go in core.

Name:           fceux
Version:        2.6.6
Release:        %mkrel 2
Summary:        A cross platform, NTSC and PAL Famicom/NES emulator
Group:          Emulators
License:        GPLv2+
URL:            https://fceux.com/
Source:         https://github.com/TASEmulators/fceux/archive/v%{version}/%{name}-%{version}.tar.gz
# From upstream:
Patch1:         0001-fix-build-errors-from-rdtsc-fixes-663.patch
Patch2:         0002-Added-feature-macro-__FCEU_X86_TSC_ENABLE-to-enable-.patch
# Mageia patches:
Patch10:        fceux-2.6.4-mga-desktop.patch
BuildRequires:  ffmpeg-devel
BuildRequires:  lua5.1-devel
BuildRequires:  pkgconfig(gdlib)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  cmake
BuildRequires:  cmake(Qt6)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6OpenGL)
BuildRequires:  cmake(Qt6OpenGLWidgets)

%description
FCEUX is a Nintendo Entertainment System (NES), Famicom, and Famicom
Disk System (FDS) emulator. It supports both PAL (European) and NTSC
(USA/JPN) modes.

The FCEUX concept is that of an "all in one" emulator that offers accurate
emulation and the best options for both casual play and a variety of more
advanced emulator functions. For pro users, FCEUX offers tools for debugging,
rom-hacking, map making, Tool-assisted movies, and Lua scripting

%files
%doc changelog.txt COPYING NewPPUtests.txt *-SDL
%doc documentation/{cheat.html,faq,todo,TODO-PROJECT,Videolog.txt}
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_mandir}/man6/%{name}.6*

#----------------------------------------------------------------------------

%package        net-server
Summary:        Server for the FCEUX emulator

%description    net-server
FCEUX clients can connect to this server and play multiplayer NES games over
the network.

%files          net-server
%doc fceux-server/{AUTHORS,ChangeLog,COPYING,README}
%{_bindir}/%{name}-net-server
%config(noreplace) %{_sysconfdir}/%{name}-server.conf
%{_mandir}/man6/%{name}-net-server.6*

#----------------------------------------------------------------------------

%prep
%autosetup -p1

# Remove bundled LUA and minizip libraries
rm -rf src/lua
rm -rf src/utils/unzip.*

# Remove Windows files
find . -name "*.dll" -delete
find . -name "*.exe" -delete

# Fix end-of-line-encoding
sed -i 's/\r//' changelog.txt NewPPUtests.txt \
  documentation/Videolog.txt \
  fceux-server/{AUTHORS,ChangeLog,README}

%build
%set_build_flags
%make_build -C fceux-server

%cmake -DQT6=ON
%cmake_build

%install
%cmake_install

# Install icon
install -D -p -m 644 %{name}1.png \
  %{buildroot}%{_iconsdir}/hicolor/512x512/apps/%{name}.png
rm -rf %{buildroot}%{_datadir}/pixmaps/

# Install server binary
install -D -p -m 755 fceux-server/fceux-net-server \
  %{buildroot}%{_bindir}/fceux-net-server

# Install server config file
install -D -p -m 644 fceux-server/fceux-server.conf \
  %{buildroot}%{_sysconfdir}/%{name}-server.conf


%changelog
* Mon Nov 11 2024 daviddavid <daviddavid> 2.6.6-2.mga10
+ Revision: 2114309
- switch to Qt6

* Sun Oct 15 2023 wally <wally> 2.6.6-1.mga10
+ Revision: 1997044
- fix non-x86 builds
- rebuild for minizip from minizip-ng
+ daviddavid <daviddavid>
- new version: 2.6.6

* Thu Dec 08 2022 daviddavid <daviddavid> 2.6.4-2.mga9
+ Revision: 1919425
- enable ffmpeg support

* Thu Dec 08 2022 daviddavid <daviddavid> 2.6.4-1.mga9
+ Revision: 1919417
- new version: 2.6.4
- remove merged upstream patch
- rediff mga-desktop patch
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Tue Mar 30 2021 wally <wally> 2.3.0-3.mga9
+ Revision: 1711949
- rebuild for armv7

* Tue Mar 30 2021 wally <wally> 2.3.0-2.mga9
+ Revision: 1711943
- rebuild with updated lua 5.1

* Sun Mar 28 2021 wally <wally> 2.3.0-1.mga9
+ Revision: 1711346
- new version 2.3.0
- switch to cmake build

* Tue Nov 03 2020 akien <akien> 2.2.3-6.mga8
+ Revision: 1642034
- Rebuild in core as it doesn't require tainted material to work

* Fri Feb 21 2020 umeabot <umeabot> 2.2.3-5.mga8.tainted
+ Revision: 1548869
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Tue Sep 17 2019 daviddavid <daviddavid> 2.2.3-4.mga8.tainted
+ Revision: 1442743
- switch to python3-scons

* Fri Apr 05 2019 daviddavid <daviddavid> 2.2.3-3.mga7.tainted
+ Revision: 1385978
- switch to Python2 scons support

* Thu Sep 20 2018 umeabot <umeabot> 2.2.3-2.mga7.tainted
+ Revision: 1278220
- Mageia 7 Mass Rebuild

* Fri Jul 29 2016 akien <akien> 2.2.3-1.mga6.tainted
+ Revision: 1043888
- Turn on RELEASE build
- Version 2.2.3

* Wed Feb 24 2016 daviddavid <daviddavid> 2.2.2-5.mga6.tainted
+ Revision: 977867
- rebuild for Mageia 6

* Mon Feb 16 2015 oden <oden> 2.2.2-4.mga5.tainted
+ Revision: 815142
- rebuilt for libgd-2.1.1

* Wed Oct 15 2014 umeabot <umeabot> 2.2.2-3.mga5.tainted
+ Revision: 747830
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.2.2-2.mga5.tainted
+ Revision: 679106
- Mageia 5 Mass Rebuild

* Sat Jun 14 2014 akien <akien> 2.2.2-1.mga5.tainted
+ Revision: 636146
- Update %%description based on the upstream website
- Remove useless stuff from %%prep section
- Add a patch to clean the desktop file
- imported package fceux from Fedora


* Wed Oct 23 2013 Andrea Musuruane <musuruan@gmail.com> - 2.2.2-2
- Added missing update of desktop database

* Sat Oct 19 2013 Andrea Musuruane <musuruan@gmail.com> - 2.2.2-1
- Updated to new upstream realease
- Removed non longer needed patches
- Built with compat-lua for F20+

* Wed Jun 12 2013 Nicolas Chauvet <kwizart@gmail.com> - 2.2.1-2
- Rebuilt for GD 2.1.0

* Tue Apr 02 2013 Andrea Musuruane <musuruan@gmail.com> - 2.2.1-1
- Updated to new upstream realease
- Packaged fceux-net-server too
- Imported Debian patches
- Enabled LUA scripting

* Sun Mar 03 2013 Nicolas Chauvet <kwizart@gmail.com> - 2.1.5-3
- Mass rebuilt for Fedora 19 Features

* Sat Apr 28 2012 Andrea Musuruane <musuruan@gmail.com> 2.1.5-2
- Obsoleted gfceu too
- Notified upstream about underlinking

* Sun Apr 22 2012 Andrea Musuruane <musuruan@gmail.com> 2.1.5-1
- First release for RPM Fusion
- LUA support is disabled because fceux uses a private header file
- Reused Gentoo and upstream patches
- Made a patch not to use the bundled minizip library

